Class: GPDDebtPositions::PaymentOptionModel

Inherits:
Object
  • Object
show all
Defined in:
lib/gpd_debtposition_api/models/payment_option_model.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentOptionModel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `GPDDebtPositions::PaymentOptionModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `GPDDebtPositions::PaymentOptionModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'nav')
    self.nav = attributes[:'nav']
  end

  if attributes.key?(:'iuv')
    self.iuv = attributes[:'iuv']
  else
    self.iuv = nil
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'is_partial_payment')
    self.is_partial_payment = attributes[:'is_partial_payment']
  else
    self.is_partial_payment = nil
  end

  if attributes.key?(:'due_date')
    self.due_date = attributes[:'due_date']
  else
    self.due_date = nil
  end

  if attributes.key?(:'retention_date')
    self.retention_date = attributes[:'retention_date']
  end

  if attributes.key?(:'fee')
    self.fee = attributes[:'fee']
  end

  if attributes.key?(:'notification_fee')
    self.notification_fee = attributes[:'notification_fee']
  end

  if attributes.key?(:'transfer')
    if (value = attributes[:'transfer']).is_a?(Array)
      self.transfer = value
    end
  end

  if attributes.key?(:'payment_option_metadata')
    if (value = attributes[:'payment_option_metadata']).is_a?(Array)
      self. = value
    end
  end
end

Instance Attribute Details

#amountObject

Returns the value of attribute amount.



22
23
24
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 22

def amount
  @amount
end

#descriptionObject

Returns the value of attribute description.



24
25
26
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 24

def description
  @description
end

#due_dateObject

Returns the value of attribute due_date.



28
29
30
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 28

def due_date
  @due_date
end

#feeObject

Returns the value of attribute fee.



32
33
34
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 32

def fee
  @fee
end

#is_partial_paymentObject

Returns the value of attribute is_partial_payment.



26
27
28
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 26

def is_partial_payment
  @is_partial_payment
end

#iuvObject

Returns the value of attribute iuv.



20
21
22
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 20

def iuv
  @iuv
end

Returns the value of attribute nav.



18
19
20
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 18

def nav
  @nav
end

#notification_feeObject

Returns the value of attribute notification_fee.



34
35
36
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 34

def notification_fee
  @notification_fee
end

#payment_option_metadataObject

it can added a maximum of 10 key-value pairs for metadata



39
40
41
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 39

def 
  
end

#retention_dateObject

Returns the value of attribute retention_date.



30
31
32
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 30

def retention_date
  @retention_date
end

#transferObject

Returns the value of attribute transfer.



36
37
38
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 36

def transfer
  @transfer
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 309

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = GPDDebtPositions.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 59

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 42

def self.attribute_map
  {
    :'nav' => :'nav',
    :'iuv' => :'iuv',
    :'amount' => :'amount',
    :'description' => :'description',
    :'is_partial_payment' => :'isPartialPayment',
    :'due_date' => :'dueDate',
    :'retention_date' => :'retentionDate',
    :'fee' => :'fee',
    :'notification_fee' => :'notificationFee',
    :'transfer' => :'transfer',
    :'payment_option_metadata' => :'paymentOptionMetadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 285

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 64

def self.openapi_types
  {
    :'nav' => :'String',
    :'iuv' => :'String',
    :'amount' => :'Integer',
    :'description' => :'String',
    :'is_partial_payment' => :'Boolean',
    :'due_date' => :'Time',
    :'retention_date' => :'Time',
    :'fee' => :'Integer',
    :'notification_fee' => :'Integer',
    :'transfer' => :'Array<TransferModel>',
    :'payment_option_metadata' => :'Array<PaymentOptionMetadataModel>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 254

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      nav == o.nav &&
      iuv == o.iuv &&
      amount == o.amount &&
      description == o.description &&
      is_partial_payment == o.is_partial_payment &&
      due_date == o.due_date &&
      retention_date == o.retention_date &&
      fee == o.fee &&
      notification_fee == o.notification_fee &&
      transfer == o.transfer &&
       == o.
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 380

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


272
273
274
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 272

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



278
279
280
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 278

def hash
  [nav, iuv, amount, description, is_partial_payment, due_date, retention_date, fee, notification_fee, transfer, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @iuv.nil?
    invalid_properties.push('invalid value for "iuv", iuv cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @description.to_s.length > 140
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 140.')
  end

  if @description.to_s.length < 0
    invalid_properties.push('invalid value for "description", the character length must be great than or equal to 0.')
  end

  if @is_partial_payment.nil?
    invalid_properties.push('invalid value for "is_partial_payment", is_partial_payment cannot be nil.')
  end

  if @due_date.nil?
    invalid_properties.push('invalid value for "due_date", due_date cannot be nil.')
  end

  if !.nil? && .length > 10
    invalid_properties.push('invalid value for "payment_option_metadata", number of items must be less than or equal to 10.')
  end

  if !.nil? && .length < 0
    invalid_properties.push('invalid value for "payment_option_metadata", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 356

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 362

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



350
351
352
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 350

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/gpd_debtposition_api/models/payment_option_model.rb', line 206

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @iuv.nil?
  return false if @amount.nil?
  return false if @description.nil?
  return false if @description.to_s.length > 140
  return false if @description.to_s.length < 0
  return false if @is_partial_payment.nil?
  return false if @due_date.nil?
  return false if !.nil? && .length > 10
  return false if !.nil? && .length < 0
  true
end