Class: GPDDebtPositions::PaymentOptionModelResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/gpd_debtposition_api/models/payment_option_model_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentOptionModelResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 149

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `GPDDebtPositions::PaymentOptionModelResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `GPDDebtPositions::PaymentOptionModelResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'nav')
    self.nav = attributes[:'nav']
  end

  if attributes.key?(:'iuv')
    self.iuv = attributes[:'iuv']
  end

  if attributes.key?(:'organization_fiscal_code')
    self.organization_fiscal_code = attributes[:'organization_fiscal_code']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'is_partial_payment')
    self.is_partial_payment = attributes[:'is_partial_payment']
  end

  if attributes.key?(:'due_date')
    self.due_date = attributes[:'due_date']
  end

  if attributes.key?(:'retention_date')
    self.retention_date = attributes[:'retention_date']
  end

  if attributes.key?(:'payment_date')
    self.payment_date = attributes[:'payment_date']
  end

  if attributes.key?(:'reporting_date')
    self.reporting_date = attributes[:'reporting_date']
  end

  if attributes.key?(:'inserted_date')
    self.inserted_date = attributes[:'inserted_date']
  end

  if attributes.key?(:'payment_method')
    self.payment_method = attributes[:'payment_method']
  end

  if attributes.key?(:'fee')
    self.fee = attributes[:'fee']
  end

  if attributes.key?(:'notification_fee')
    self.notification_fee = attributes[:'notification_fee']
  end

  if attributes.key?(:'psp_company')
    self.psp_company = attributes[:'psp_company']
  end

  if attributes.key?(:'id_receipt')
    self.id_receipt = attributes[:'id_receipt']
  end

  if attributes.key?(:'id_flow_reporting')
    self.id_flow_reporting = attributes[:'id_flow_reporting']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'last_updated_date')
    self.last_updated_date = attributes[:'last_updated_date']
  end

  if attributes.key?(:'payment_option_metadata')
    if (value = attributes[:'payment_option_metadata']).is_a?(Array)
      self. = value
    end
  end

  if attributes.key?(:'transfer')
    if (value = attributes[:'transfer']).is_a?(Array)
      self.transfer = value
    end
  end
end

Instance Attribute Details

#amountObject

Returns the value of attribute amount.



24
25
26
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 24

def amount
  @amount
end

#descriptionObject

Returns the value of attribute description.



26
27
28
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 26

def description
  @description
end

#due_dateObject

Returns the value of attribute due_date.



30
31
32
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 30

def due_date
  @due_date
end

#feeObject

Returns the value of attribute fee.



42
43
44
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 42

def fee
  @fee
end

#id_flow_reportingObject

Returns the value of attribute id_flow_reporting.



50
51
52
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 50

def id_flow_reporting
  @id_flow_reporting
end

#id_receiptObject

Returns the value of attribute id_receipt.



48
49
50
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 48

def id_receipt
  @id_receipt
end

#inserted_dateObject

Returns the value of attribute inserted_date.



38
39
40
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 38

def inserted_date
  @inserted_date
end

#is_partial_paymentObject

Returns the value of attribute is_partial_payment.



28
29
30
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 28

def is_partial_payment
  @is_partial_payment
end

#iuvObject

Returns the value of attribute iuv.



20
21
22
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 20

def iuv
  @iuv
end

#last_updated_dateObject

Returns the value of attribute last_updated_date.



54
55
56
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 54

def last_updated_date
  @last_updated_date
end

Returns the value of attribute nav.



18
19
20
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 18

def nav
  @nav
end

#notification_feeObject

Returns the value of attribute notification_fee.



44
45
46
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 44

def notification_fee
  @notification_fee
end

#organization_fiscal_codeObject

Returns the value of attribute organization_fiscal_code.



22
23
24
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 22

def organization_fiscal_code
  @organization_fiscal_code
end

#payment_dateObject

Returns the value of attribute payment_date.



34
35
36
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 34

def payment_date
  @payment_date
end

#payment_methodObject

Returns the value of attribute payment_method.



40
41
42
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 40

def payment_method
  @payment_method
end

#payment_option_metadataObject

Returns the value of attribute payment_option_metadata.



56
57
58
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 56

def 
  @payment_option_metadata
end

#psp_companyObject

Returns the value of attribute psp_company.



46
47
48
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 46

def psp_company
  @psp_company
end

#reporting_dateObject

Returns the value of attribute reporting_date.



36
37
38
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 36

def reporting_date
  @reporting_date
end

#retention_dateObject

Returns the value of attribute retention_date.



32
33
34
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 32

def retention_date
  @retention_date
end

#statusObject

Returns the value of attribute status.



52
53
54
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 52

def status
  @status
end

#transferObject

Returns the value of attribute transfer.



58
59
60
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 58

def transfer
  @transfer
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 345

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = GPDDebtPositions.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 110

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 83

def self.attribute_map
  {
    :'nav' => :'nav',
    :'iuv' => :'iuv',
    :'organization_fiscal_code' => :'organizationFiscalCode',
    :'amount' => :'amount',
    :'description' => :'description',
    :'is_partial_payment' => :'isPartialPayment',
    :'due_date' => :'dueDate',
    :'retention_date' => :'retentionDate',
    :'payment_date' => :'paymentDate',
    :'reporting_date' => :'reportingDate',
    :'inserted_date' => :'insertedDate',
    :'payment_method' => :'paymentMethod',
    :'fee' => :'fee',
    :'notification_fee' => :'notificationFee',
    :'psp_company' => :'pspCompany',
    :'id_receipt' => :'idReceipt',
    :'id_flow_reporting' => :'idFlowReporting',
    :'status' => :'status',
    :'last_updated_date' => :'lastUpdatedDate',
    :'payment_option_metadata' => :'paymentOptionMetadata',
    :'transfer' => :'transfer'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 321

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



142
143
144
145
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 142

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 115

def self.openapi_types
  {
    :'nav' => :'String',
    :'iuv' => :'String',
    :'organization_fiscal_code' => :'String',
    :'amount' => :'Integer',
    :'description' => :'String',
    :'is_partial_payment' => :'Boolean',
    :'due_date' => :'Time',
    :'retention_date' => :'Time',
    :'payment_date' => :'Time',
    :'reporting_date' => :'Time',
    :'inserted_date' => :'Time',
    :'payment_method' => :'String',
    :'fee' => :'Integer',
    :'notification_fee' => :'Integer',
    :'psp_company' => :'String',
    :'id_receipt' => :'String',
    :'id_flow_reporting' => :'String',
    :'status' => :'String',
    :'last_updated_date' => :'Time',
    :'payment_option_metadata' => :'Array<PaymentOptionMetadataModelResponse>',
    :'transfer' => :'Array<TransferModelResponse>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 280

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      nav == o.nav &&
      iuv == o.iuv &&
      organization_fiscal_code == o.organization_fiscal_code &&
      amount == o.amount &&
      description == o.description &&
      is_partial_payment == o.is_partial_payment &&
      due_date == o.due_date &&
      retention_date == o.retention_date &&
      payment_date == o.payment_date &&
      reporting_date == o.reporting_date &&
      inserted_date == o.inserted_date &&
      payment_method == o.payment_method &&
      fee == o.fee &&
      notification_fee == o.notification_fee &&
      psp_company == o.psp_company &&
      id_receipt == o.id_receipt &&
      id_flow_reporting == o.id_flow_reporting &&
      status == o.status &&
      last_updated_date == o.last_updated_date &&
       == o. &&
      transfer == o.transfer
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 416

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


308
309
310
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 308

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



314
315
316
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 314

def hash
  [nav, iuv, organization_fiscal_code, amount, description, is_partial_payment, due_date, retention_date, payment_date, reporting_date, inserted_date, payment_method, fee, notification_fee, psp_company, id_receipt, id_flow_reporting, status, last_updated_date, , transfer].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



253
254
255
256
257
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 253

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



392
393
394
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 392

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 398

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



386
387
388
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 386

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



261
262
263
264
265
266
# File 'lib/gpd_debtposition_api/models/payment_option_model_response.rb', line 261

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["PO_UNPAID", "PO_PAID", "PO_PARTIALLY_REPORTED", "PO_REPORTED"])
  return false unless status_validator.valid?(@status)
  true
end