Class: GPDDebtPositions::PaymentPositionModelBaseResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/gpd_debtposition_api/models/payment_position_model_base_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentPositionModelBaseResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `GPDDebtPositions::PaymentPositionModelBaseResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `GPDDebtPositions::PaymentPositionModelBaseResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'iupd')
    self.iupd = attributes[:'iupd']
  end

  if attributes.key?(:'aca')
    self.aca = attributes[:'aca']
  else
    self.aca = false
  end

  if attributes.key?(:'pay_stand_in')
    self.pay_stand_in = attributes[:'pay_stand_in']
  else
    self.pay_stand_in = true
  end

  if attributes.key?(:'organization_fiscal_code')
    self.organization_fiscal_code = attributes[:'organization_fiscal_code']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'company_name')
    self.company_name = attributes[:'company_name']
  end

  if attributes.key?(:'office_name')
    self.office_name = attributes[:'office_name']
  end

  if attributes.key?(:'inserted_date')
    self.inserted_date = attributes[:'inserted_date']
  end

  if attributes.key?(:'publish_date')
    self.publish_date = attributes[:'publish_date']
  end

  if attributes.key?(:'validity_date')
    self.validity_date = attributes[:'validity_date']
  end

  if attributes.key?(:'payment_date')
    self.payment_date = attributes[:'payment_date']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'last_updated_date')
    self.last_updated_date = attributes[:'last_updated_date']
  end

  if attributes.key?(:'payment_option')
    if (value = attributes[:'payment_option']).is_a?(Array)
      self.payment_option = value
    end
  end
end

Instance Attribute Details

#acaObject

Returns the value of attribute aca.



20
21
22
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 20

def aca
  @aca
end

#company_nameObject

Returns the value of attribute company_name.



28
29
30
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 28

def company_name
  @company_name
end

#inserted_dateObject

Returns the value of attribute inserted_date.



32
33
34
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 32

def inserted_date
  @inserted_date
end

#iupdObject

Returns the value of attribute iupd.



18
19
20
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 18

def iupd
  @iupd
end

#last_updated_dateObject

Returns the value of attribute last_updated_date.



42
43
44
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 42

def last_updated_date
  @last_updated_date
end

#office_nameObject

Returns the value of attribute office_name.



30
31
32
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 30

def office_name
  @office_name
end

#organization_fiscal_codeObject

Returns the value of attribute organization_fiscal_code.



24
25
26
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 24

def organization_fiscal_code
  @organization_fiscal_code
end

#pay_stand_inObject

Returns the value of attribute pay_stand_in.



22
23
24
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 22

def pay_stand_in
  @pay_stand_in
end

#payment_dateObject

Returns the value of attribute payment_date.



38
39
40
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 38

def payment_date
  @payment_date
end

#payment_optionObject

Returns the value of attribute payment_option.



44
45
46
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 44

def payment_option
  @payment_option
end

#publish_dateObject

Returns the value of attribute publish_date.



34
35
36
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 34

def publish_date
  @publish_date
end

#statusObject

Returns the value of attribute status.



40
41
42
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 40

def status
  @status
end

#typeObject

Returns the value of attribute type.



26
27
28
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 26

def type
  @type
end

#validity_dateObject

Returns the value of attribute validity_date.



36
37
38
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 36

def validity_date
  @validity_date
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 296

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = GPDDebtPositions.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 69

def self.attribute_map
  {
    :'iupd' => :'iupd',
    :'aca' => :'aca',
    :'pay_stand_in' => :'payStandIn',
    :'organization_fiscal_code' => :'organizationFiscalCode',
    :'type' => :'type',
    :'company_name' => :'companyName',
    :'office_name' => :'officeName',
    :'inserted_date' => :'insertedDate',
    :'publish_date' => :'publishDate',
    :'validity_date' => :'validityDate',
    :'payment_date' => :'paymentDate',
    :'status' => :'status',
    :'last_updated_date' => :'lastUpdatedDate',
    :'payment_option' => :'paymentOption'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 272

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 114

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 94

def self.openapi_types
  {
    :'iupd' => :'String',
    :'aca' => :'Boolean',
    :'pay_stand_in' => :'Boolean',
    :'organization_fiscal_code' => :'String',
    :'type' => :'String',
    :'company_name' => :'String',
    :'office_name' => :'String',
    :'inserted_date' => :'Time',
    :'publish_date' => :'Time',
    :'validity_date' => :'Time',
    :'payment_date' => :'Time',
    :'status' => :'String',
    :'last_updated_date' => :'Time',
    :'payment_option' => :'Array<PaymentOptionModelResponse>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 238

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      iupd == o.iupd &&
      aca == o.aca &&
      pay_stand_in == o.pay_stand_in &&
      organization_fiscal_code == o.organization_fiscal_code &&
      type == o.type &&
      company_name == o.company_name &&
      office_name == o.office_name &&
      inserted_date == o.inserted_date &&
      publish_date == o.publish_date &&
      validity_date == o.validity_date &&
      payment_date == o.payment_date &&
      status == o.status &&
      last_updated_date == o.last_updated_date &&
      payment_option == o.payment_option
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 367

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


259
260
261
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 259

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



265
266
267
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 265

def hash
  [iupd, aca, pay_stand_in, organization_fiscal_code, type, company_name, office_name, inserted_date, publish_date, validity_date, payment_date, status, last_updated_date, payment_option].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



199
200
201
202
203
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 199

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



343
344
345
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 343

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 349

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



337
338
339
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 337

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



207
208
209
210
211
212
213
214
# File 'lib/gpd_debtposition_api/models/payment_position_model_base_response.rb', line 207

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["F", "G"])
  return false unless type_validator.valid?(@type)
  status_validator = EnumAttributeValidator.new('String', ["DRAFT", "PUBLISHED", "VALID", "INVALID", "EXPIRED", "PARTIALLY_PAID", "PAID", "REPORTED"])
  return false unless status_validator.valid?(@status)
  true
end