Class: GPDDebtPositions::TransferModel
- Inherits:
-
Object
- Object
- GPDDebtPositions::TransferModel
- Defined in:
- lib/gpd_debtposition_api/models/transfer_model.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#category ⇒ Object
Returns the value of attribute category.
-
#iban ⇒ Object
mutual exclusive with stamp.
-
#id_transfer ⇒ Object
Returns the value of attribute id_transfer.
-
#organization_fiscal_code ⇒ Object
Fiscal code related to the organization targeted by this transfer.
-
#postal_iban ⇒ Object
optional - can be combined with iban but not with stamp.
-
#remittance_information ⇒ Object
Returns the value of attribute remittance_information.
-
#stamp ⇒ Object
Returns the value of attribute stamp.
-
#transfer_metadata ⇒ Object
it can added a maximum of 10 key-value pairs for metadata.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TransferModel
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TransferModel
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `GPDDebtPositions::TransferModel` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `GPDDebtPositions::TransferModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id_transfer') self.id_transfer = attributes[:'id_transfer'] else self.id_transfer = nil end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'organization_fiscal_code') self.organization_fiscal_code = attributes[:'organization_fiscal_code'] end if attributes.key?(:'remittance_information') self.remittance_information = attributes[:'remittance_information'] else self.remittance_information = nil end if attributes.key?(:'category') self.category = attributes[:'category'] else self.category = nil end if attributes.key?(:'iban') self.iban = attributes[:'iban'] end if attributes.key?(:'postal_iban') self.postal_iban = attributes[:'postal_iban'] end if attributes.key?(:'stamp') self.stamp = attributes[:'stamp'] end if attributes.key?(:'transfer_metadata') if (value = attributes[:'transfer_metadata']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount.
20 21 22 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 20 def amount @amount end |
#category ⇒ Object
Returns the value of attribute category.
27 28 29 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 27 def category @category end |
#iban ⇒ Object
mutual exclusive with stamp
30 31 32 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 30 def iban @iban end |
#id_transfer ⇒ Object
Returns the value of attribute id_transfer.
18 19 20 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 18 def id_transfer @id_transfer end |
#organization_fiscal_code ⇒ Object
Fiscal code related to the organization targeted by this transfer.
23 24 25 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 23 def organization_fiscal_code @organization_fiscal_code end |
#postal_iban ⇒ Object
optional - can be combined with iban but not with stamp
33 34 35 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 33 def postal_iban @postal_iban end |
#remittance_information ⇒ Object
Returns the value of attribute remittance_information.
25 26 27 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 25 def remittance_information @remittance_information end |
#stamp ⇒ Object
Returns the value of attribute stamp.
35 36 37 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 35 def stamp @stamp end |
#transfer_metadata ⇒ Object
it can added a maximum of 10 key-value pairs for metadata
38 39 40 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 38 def end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 291 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = GPDDebtPositions.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 78 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 63 def self.attribute_map { :'id_transfer' => :'idTransfer', :'amount' => :'amount', :'organization_fiscal_code' => :'organizationFiscalCode', :'remittance_information' => :'remittanceInformation', :'category' => :'category', :'iban' => :'iban', :'postal_iban' => :'postalIban', :'stamp' => :'stamp', :'transfer_metadata' => :'transferMetadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 267 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 83 def self.openapi_types { :'id_transfer' => :'String', :'amount' => :'Integer', :'organization_fiscal_code' => :'String', :'remittance_information' => :'String', :'category' => :'String', :'iban' => :'String', :'postal_iban' => :'String', :'stamp' => :'Stamp', :'transfer_metadata' => :'Array<TransferMetadataModel>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 238 def ==(o) return true if self.equal?(o) self.class == o.class && id_transfer == o.id_transfer && amount == o.amount && organization_fiscal_code == o.organization_fiscal_code && remittance_information == o.remittance_information && category == o.category && iban == o.iban && postal_iban == o.postal_iban && stamp == o.stamp && == o. end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 362 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
254 255 256 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 254 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
260 261 262 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 260 def hash [id_transfer, amount, organization_fiscal_code, remittance_information, category, iban, postal_iban, stamp, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id_transfer.nil? invalid_properties.push('invalid value for "id_transfer", id_transfer cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @remittance_information.nil? invalid_properties.push('invalid value for "remittance_information", remittance_information cannot be nil.') end if @category.nil? invalid_properties.push('invalid value for "category", category cannot be nil.') end if !.nil? && .length > 10 invalid_properties.push('invalid value for "transfer_metadata", number of items must be less than or equal to 10.') end if !.nil? && .length < 0 invalid_properties.push('invalid value for "transfer_metadata", number of items must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
338 339 340 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 338 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 344 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
332 333 334 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 332 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/gpd_debtposition_api/models/transfer_model.rb', line 199 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id_transfer.nil? id_transfer_validator = EnumAttributeValidator.new('String', ["1", "2", "3", "4", "5"]) return false unless id_transfer_validator.valid?(@id_transfer) return false if @amount.nil? return false if @remittance_information.nil? return false if @category.nil? return false if !.nil? && .length > 10 return false if !.nil? && .length < 0 true end |