Class: GPDDebtPositions::TransferModelResponse
- Inherits:
-
Object
- Object
- GPDDebtPositions::TransferModelResponse
- Defined in:
- lib/gpd_debtposition_api/models/transfer_model_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#category ⇒ Object
Returns the value of attribute category.
-
#iban ⇒ Object
Returns the value of attribute iban.
-
#id_transfer ⇒ Object
Returns the value of attribute id_transfer.
-
#inserted_date ⇒ Object
Returns the value of attribute inserted_date.
-
#last_updated_date ⇒ Object
Returns the value of attribute last_updated_date.
-
#organization_fiscal_code ⇒ Object
Returns the value of attribute organization_fiscal_code.
-
#postal_iban ⇒ Object
Returns the value of attribute postal_iban.
-
#remittance_information ⇒ Object
Returns the value of attribute remittance_information.
-
#stamp ⇒ Object
Returns the value of attribute stamp.
-
#status ⇒ Object
Returns the value of attribute status.
-
#transfer_metadata ⇒ Object
Returns the value of attribute transfer_metadata.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TransferModelResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TransferModelResponse
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `GPDDebtPositions::TransferModelResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `GPDDebtPositions::TransferModelResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'organization_fiscal_code') self.organization_fiscal_code = attributes[:'organization_fiscal_code'] end if attributes.key?(:'id_transfer') self.id_transfer = attributes[:'id_transfer'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'remittance_information') self.remittance_information = attributes[:'remittance_information'] end if attributes.key?(:'category') self.category = attributes[:'category'] end if attributes.key?(:'iban') self.iban = attributes[:'iban'] end if attributes.key?(:'postal_iban') self.postal_iban = attributes[:'postal_iban'] end if attributes.key?(:'stamp') self.stamp = attributes[:'stamp'] end if attributes.key?(:'inserted_date') self.inserted_date = attributes[:'inserted_date'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'last_updated_date') self.last_updated_date = attributes[:'last_updated_date'] end if attributes.key?(:'transfer_metadata') if (value = attributes[:'transfer_metadata']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount.
22 23 24 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 22 def amount @amount end |
#category ⇒ Object
Returns the value of attribute category.
26 27 28 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 26 def category @category end |
#iban ⇒ Object
Returns the value of attribute iban.
28 29 30 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 28 def iban @iban end |
#id_transfer ⇒ Object
Returns the value of attribute id_transfer.
20 21 22 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 20 def id_transfer @id_transfer end |
#inserted_date ⇒ Object
Returns the value of attribute inserted_date.
34 35 36 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 34 def inserted_date @inserted_date end |
#last_updated_date ⇒ Object
Returns the value of attribute last_updated_date.
38 39 40 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 38 def last_updated_date @last_updated_date end |
#organization_fiscal_code ⇒ Object
Returns the value of attribute organization_fiscal_code.
18 19 20 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 18 def organization_fiscal_code @organization_fiscal_code end |
#postal_iban ⇒ Object
Returns the value of attribute postal_iban.
30 31 32 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 30 def postal_iban @postal_iban end |
#remittance_information ⇒ Object
Returns the value of attribute remittance_information.
24 25 26 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 24 def remittance_information @remittance_information end |
#stamp ⇒ Object
Returns the value of attribute stamp.
32 33 34 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 32 def stamp @stamp end |
#status ⇒ Object
Returns the value of attribute status.
36 37 38 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 36 def status @status end |
#transfer_metadata ⇒ Object
Returns the value of attribute transfer_metadata.
40 41 42 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 40 def @transfer_metadata end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 262 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = GPDDebtPositions.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 83 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 65 def self.attribute_map { :'organization_fiscal_code' => :'organizationFiscalCode', :'id_transfer' => :'idTransfer', :'amount' => :'amount', :'remittance_information' => :'remittanceInformation', :'category' => :'category', :'iban' => :'iban', :'postal_iban' => :'postalIban', :'stamp' => :'stamp', :'inserted_date' => :'insertedDate', :'status' => :'status', :'last_updated_date' => :'lastUpdatedDate', :'transfer_metadata' => :'transferMetadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 238 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 106 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 88 def self.openapi_types { :'organization_fiscal_code' => :'String', :'id_transfer' => :'String', :'amount' => :'Integer', :'remittance_information' => :'String', :'category' => :'String', :'iban' => :'String', :'postal_iban' => :'String', :'stamp' => :'Stamp', :'inserted_date' => :'Time', :'status' => :'String', :'last_updated_date' => :'Time', :'transfer_metadata' => :'Array<TransferMetadataModelResponse>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 206 def ==(o) return true if self.equal?(o) self.class == o.class && organization_fiscal_code == o.organization_fiscal_code && id_transfer == o.id_transfer && amount == o.amount && remittance_information == o.remittance_information && category == o.category && iban == o.iban && postal_iban == o.postal_iban && stamp == o.stamp && inserted_date == o.inserted_date && status == o.status && last_updated_date == o.last_updated_date && == o. end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 333 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
225 226 227 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 225 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
231 232 233 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 231 def hash [organization_fiscal_code, id_transfer, amount, remittance_information, category, iban, postal_iban, stamp, inserted_date, status, last_updated_date, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
179 180 181 182 183 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 179 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
309 310 311 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 309 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 315 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
303 304 305 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 303 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
187 188 189 190 191 192 |
# File 'lib/gpd_debtposition_api/models/transfer_model_response.rb', line 187 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["T_UNREPORTED", "T_REPORTED"]) return false unless status_validator.valid?(@status) true end |